#!/usr/bin/python

"""PLOT3D file value peeker

This script reads a PLOT3D file pair and displays the values on stdout.
"""

# Copyright (c) 2006 Francesco Poli <frx@firenze.linux.it>
# 
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

__author__ = "Francesco Poli"
__progname__ = "list_plot3d"
__version__ = "0.1"
__copyright__ = "Copyright (c) 2006 Francesco Poli"
__license__ = "Expat/MIT"

import vtk

reader = vtk.vtkPLOT3DReader()
reader.SetXYZFileName("tiny.xyz")
reader.SetQFileName("tiny.q")
reader.AbortExecuteOff()
reader.BinaryFileOn()
reader.DoNotReduceNumberOfOutputsOn()
reader.ForceReadOff()
reader.HasByteCountOn()
reader.IBlankingOff()
reader.MultiGridOn()
reader.ReleaseDataFlagOff()
reader.TwoDimensionalGeometryOff()
reader.SetByteOrderToLittleEndian()
reader.SetGamma(1.4)
reader.SetR(1.0)
reader.DebugOff()
reader.Update()

ecode = reader.GetErrorCode()
nouts = reader.GetNumberOfOutputs()
print "ErrorCode:       ", ecode,      \
    "\nNumberOfOutputs: ", nouts

for out in range(0, nouts):

    output = reader.GetOutput(out)
    data   = output.GetPointData()

    density  = data.GetArray("Density")
    momentum = data.GetArray("Momentum")
    energy   = data.GetArray("StagnationEnergy")

    npoints = output.GetNumberOfPoints()
    print "\n =====> Block #" + str(out+1) + ": ", npoints, "nodes <====="

    print "            x    y    z     density momentum_x momentum_y momentum_z     energy"
    for pt_id in range(0, npoints):
        print " node #" + str(pt_id+1)                         \
          + ": %4.1f %4.1f %4.1f " % output.GetPoint(pt_id)    \
          + "%10.4g " % density.GetComponent(pt_id, 0)         \
          + "%10.4g %10.4g %10.4g " % momentum.GetTuple3(pt_id) \
          + "%10.4g" % energy.GetComponent(pt_id, 0)

